@@ -1,6 +1,6 @@
 /* cmdline.c - preload command-line options handling routines
  *
- * Copyright (C) 2005  Behdad Esfahbod
+ * Copyright (C) 2005,2006,2007  Behdad Esfahbod
  *
  * This file is part of preload.
  * 
@@ -38,7 +38,7 @@ static const struct option const opts[] = {
   {"statefile", 1, 0, 's'},
   {"logfile", 1, 0, 'l'},
   {"foreground", 0, 0, 'f'},
-  {"nice", 0, 0, 'n'},
+  {"nice", 1, 0, 'n'},
   {"verbose", 1, 0, 'V'},
   {"debug", 0, 0, 'd'},
   {NULL, 0, 0, 0},
@@ -129,7 +129,7 @@ preload_cmdline_parse (int *argc, char ***argv)
 static void
 version_func (void)
 {
-  printf ("%s\n\nCopyright (C) 2005 Behdad Esfahbod.\n"
+  printf ("%s\n\nCopyright (C) 2005,2006,2007,2008 Behdad Esfahbod.\n"
 	  "This is free software; see the source for copying conditions.  There is NO\n"
 	  "warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n"
 	  "\n"
@@ -165,7 +165,7 @@ help_func (gboolean err, gboolean help2man)
       fprintf (f, "  -%c, --%-*s  %s\n",
 	       opt->val, max, opt->name,
 	       opt->val == 'h' && help2man ? help2man_str : *hlp);
-      if (*dft && !help2man)
+      if (*dft)
 	fprintf (f, "          %*s(default is %s)\n", max, "", *dft);
     }
 
