@@ -13,8 +13,12 @@
 #include <errno.h>
 #include <fcntl.h>
 #include <sys/mman.h>
+#ifdef HAVE_SYS_TYPES_H
 #include <sys/types.h>
+#endif
+#ifdef HAVE_SYS_STAT_H
 #include <sys/stat.h>
+#endif
 
 
 #include <glib.h>
