@@ -37,6 +37,7 @@ set_default_conf (preload_conf_t *conf)
 #define false FALSE
 #define default_integer(def, unit) (unit * def)
 #define default_boolean(def, unit) def
+#define default_enum(def, unit) def
 #define default_string_list(def, unit) NULL
 #define confkey(grp, type, key, def, unit) \
       conf->grp.key = default_##type (def, unit);
@@ -65,6 +66,7 @@ preload_conf_load (const char *conffile, gboolean fail)
       }
 
 #define get_integer(grp, key, unit) (unit * g_key_file_get_integer (f, grp, key, &e))
+#define get_enum(grp, key, unit) (g_key_file_get_integer (f, grp, key, &e))
 #define get_boolean(grp, key, unit) g_key_file_get_boolean (f, grp, key, &e)
 #define get_string_list(grp, key, unit) g_key_file_get_string_list (f, grp, key, NULL, &e)
 #define confkey(grp, type, key, def, unit) \
@@ -108,6 +110,8 @@ preload_conf_dump_log (void)
   fprintf (stderr, "# loaded configuration at %s", timestr);
 #define print_integer(v, unit) \
 	fprintf (stderr, "%d", v / unit);
+#define print_enum(v, unit) \
+	fprintf (stderr, "%d", v);
 #define print_boolean(v, unit) \
 	fprintf (stderr, "%s", v ? "true" : "false");
 #define print_string(v, unit) \
