@@ -12,6 +12,7 @@
 
 #define signed_integer_percent	   1
 
+#define processes	   1
 
 
 typedef struct _preload_conf_t
@@ -36,8 +37,17 @@ typedef struct _preload_conf_t
     gboolean doscan;
     gboolean dopredict;
     int autosave;
+
     char **mapprefix;
     char **exeprefix;
+
+    int maxprocs;
+    enum {
+      SORT_NONE  = 0,
+      SORT_PATH  = 1,
+      SORT_INODE = 2,
+      SORT_BLOCK = 3
+    } sortstrategy;
   } system;
 
 } preload_conf_t;
