@@ -111,7 +111,7 @@ proc_get_maps (pid_t pid, GHashTable *maps, GSet **exemaps)
       long start, end, offset, length;
       int count;
 
-      count = sscanf (buffer, "%lx-%lx %*15s %lx %*u:%*u %*u %"FILELENSTR"s",
+      count = sscanf (buffer, "%lx-%lx %*15s %lx %*x:%*x %*u %"FILELENSTR"s",
 		      &start, &end, &offset, file);
 
       if (count != 4 || !sanitize_file (file) || !accept_file (file, conf->system.mapprefix))
