@@ -215,12 +215,14 @@ preload_prophet_readahead (GPtrArray *maps_arr)
       map_prob_print (map);
   }
 
-  g_message ("%dkb available for preloading, using %dkb of it",
+  g_debug ("%dkb available for preloading, using %dkb of it",
 	   memavailtotal, memavailtotal - memavail);
 
   if (i) {
-    g_message ("readaheading %d files", i);
-    preload_readahead ((preload_map_t **)maps_arr->pdata, i);
+    i = preload_readahead ((preload_map_t **)maps_arr->pdata, i);
+    g_debug ("readahead %d files", i);
+  } else {
+    g_debug ("nothing to readahead");
   }
 }
 
