@@ -3,6 +3,6 @@
 
 #include <state.h>
 
-void preload_readahead (preload_map_t **files, int file_count);
+int preload_readahead (preload_map_t **files, int file_count);
 
 #endif
