@@ -6,7 +6,7 @@ set -e
 
 echo Testing preload with preconf.conf.debug config file
 ( sleep 1; killall ./preload 2>/dev/null ) &
-./preload -c $srcdir/preload.conf.debug -s '' -d
+./preload -c preload.conf -s '' -d
 
 echo Testing preload with preconf.conf config file
 ( sleep 1; killall ./preload 2>/dev/null ) &
